Dask interface to Azure-Datalake Storage
----------------------------------------

Warning: this code is experimental and untested.

To install the backend, do ``import adlfs``, which will allow for URLs starting with ``"adl://"`` in
dask functions.